package net.sf.snmpadaptor4j.daemon.mib;

import net.sf.snmpadaptor4j.daemon.mib.jmx.xml.jaxb.MBeanAttributeType;

/**
 * Enumeration of SNMP data type.
 * @author Jean-Philippe MINETTI
 */
public enum SnmpDataType {

	/**
	 * Signed 32-bit integer.
	 */
	integer32,

	/**
	 * Non-negative 32-bit integer.
	 */
	unsigned32,

	/**
	 * Non-negative 32-bit gauge.
	 */
	gauge32,

	/**
	 * Non-negative, non-decreasing and not-writable 32-bit integer for a counter.
	 */
	counter32,

	/**
	 * Non-negative, non-decreasing and not-writable 64-bit integer for a counter.
	 */
	counter64,

	/**
	 * Non-negative and non-decreasing 32-bit integer for an elapsed time in hundredths of a second between two epochs.
	 */
	timeTicks,

	/**
	 * Array of ASCII code.
	 */
	octetString,

	/**
	 * Internet address.
	 */
	ipAddress,

	/**
	 * OID of SNMP <b>M</b>anagement <b>I</b>nformation <b>B</b>ase (MIB).
	 */
	objectIdentifier,

	/**
	 * Any data type.
	 */
	opaque;

	/**
	 * Returns a SNMP data type by its XSD item.
	 * @param xsdType XSD item of SNMP data type.
	 * @return SNMP data type.
	 */
	public static SnmpDataType valueOf (final MBeanAttributeType xsdType) {
		return SnmpDataType.valueOf(xsdType.value());
	}

}