package net.sf.snmpadaptor4j.daemon.mib;

import java.util.SortedMap;

/**
 * Object representing the <b>M</b>anagement <b>I</b>nformation <b>B</b>ase (MIB) of SNMP daemon.
 * @author Jean-Philippe MINETTI
 */
public interface SnmpMib {

	/**
	 * Finds a {@link SnmpMibExternalNode} by its OID.
	 * @param oid OID of {@link SnmpMibExternalNode} to find.
	 * @return {@link SnmpMibExternalNode} found or <code>NULL</code> if not found.
	 */
	SnmpMibExternalNode find (SnmpOid oid);

	/**
	 * Finds the next {@link SnmpMibExternalNode} from an OID
	 * @param oid OID not included in the research but from which it begins.
	 * @return {@link SnmpMibExternalNode} found or <code>NULL</code> if not found.
	 */
	SnmpMibExternalNode next (SnmpOid oid);

	/**
	 * Finds the list of next {@link SnmpMibExternalNode} from an OID
	 * @param oid OID not included in the research but from which it begins.
	 * @return List of {@link SnmpMibExternalNode} found (never <code>NULL</code>).
	 */
	SortedMap<SnmpOid, SnmpMibExternalNode> nextSet (SnmpOid oid);

}