package net.sf.snmpadaptor4j.daemon.mib;


/**
 * Object representing an external node of the SNMP <b>M</b>anagement <b>I</b>nformation <b>B</b>ase (MIB).
 * @author Jean-Philippe MINETTI
 */
public interface SnmpMibExternalNode {

	/**
	 * Returns the <b>O</b>bject <b>ID</b>entifier (OID) of MIB node.
	 * @return Object Identifier of MIB node.
	 */
	SnmpOid getOid ();

	/**
	 * Returns the SNMP data type of MIB node.
	 * @return SNMP data type of MIB node.
	 */
	SnmpDataType getSnmpDataType ();

	/**
	 * Returns the data type of JMX attribute.
	 * @return Data type of JMX attribute.
	 */
	Class<?> getJmxDataType ();

	/**
	 * Returns the value of MIB node.
	 * @return Value of MIB node.
	 * @throws Exception Exception if an error occurred.
	 */
	Object getValue () throws Exception;

	/**
	 * Sets the value of MIB node.
	 * @param value New value of MIB node.
	 * @throws Exception Exception if an error occurred.
	 */
	void setValue (Object value) throws Exception;

	/**
	 * Returns <code>TRUE</code> if the attribute can be read (for SNMP write and read community), <code>FALSE</code> otherwise.
	 * @return <code>TRUE</code> if the attribute can be read.
	 */
	boolean isReadable ();

	/**
	 * Returns <code>TRUE</code> if the attribute can be write (for SNMP write community), <code>FALSE</code> otherwise.
	 * @return <code>TRUE</code> if the attribute can be write.
	 */
	boolean isWritable ();

}