package net.sf.snmpadaptor4j.daemon.mib.jmx.xml;

import java.net.URL;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.Unmarshaller;
import net.sf.snmpadaptor4j.daemon.mib.jmx.xml.jaxb.Mapping;

/**
 * Parser of SNMP mapping file (XML).
 * @author Jean-Philippe MINETTI
 */
public final class XmlMappingParser {

	/**
	 * {@link URL} to the SNMP mapping file.
	 */
	private final URL url;

	/**
	 * JAXB representation of the SNMP mapping file.
	 */
	private JAXBElement<Mapping> jaxbElement = null;

	/**
	 * Constructor.
	 * @param url {@link URL} to the SNMP mapping file.
	 */
	public XmlMappingParser (final URL url) {
		super();
		this.url = url;
	}

	/**
	 * Loads the SNMP mapping file.
	 * @throws Exception Exception if an error occurred.
	 */
	@SuppressWarnings("unchecked")
	public void load () throws Exception {
		final JAXBContext jaxbContext = JAXBContext.newInstance(Mapping.class.getPackage().getName());
		final Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
		this.jaxbElement = (JAXBElement<Mapping>) unmarshaller.unmarshal(this.url);
	}

	/**
	 * Returns the content of the SNMP mapping file.
	 * @return Content of the SNMP mapping file.
	 */
	public Mapping getMapping () {
		return this.jaxbElement.getValue();
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString () {
		return "XmlMappingParser[" + this.url + "]";
	}

}